![nomad plugin logo](assets/nomad-plugin-logo.png)

# Welcome to the `nomad-catalysis` documentation

This is the documentation for the NOMAD plugin for heterogeneous catalysis data. It
provides an overview of the supported entry types, their sub-sections and quantities and
a guide of how to use the plugin and effectively manage and share catalysis research data
in NOMAD.

This plugin was developed as part of Task Area E2 "Heterogeneous Catalysis" of the
[FAIRmat](https://www.fairmat-nfdi.eu/fairmat) project within the German National Research Data
Infrastucture ([NFDI](https://www.nfdi.de)). The release v1.0.2 is part of the [central NOMAD repository](https://nomad-lab.eu/prod/v1/gui/search/heterogeneouscatalyst) deployment. The latest features of the main branch can be tested in the
[Example Oasis](https://nomad-lab.eu/prod/v1/oasis/gui/) provided by FAIRmat/NOMAD-lab.
NOMAD facilitates the collection, storage, analysis and dissemination of research data,
adhering to the principles of FAIR (Findable, Accessible, Interoperable, and Reusable)
data management.


## Introduction

This plugin aims at facilitating the catalysis researcher's life by providing a flexible
tool to manage, visualize, analyze and share catalyst and reactivity data. It is still in development and feedback about the plugin and documentation is always welcome.

## Included Entry Types
This plugin includes the following NOMAD entry types: 

- `CatalystSample` 
- `CatalyticReaction`
- `CatalysisCollectionParserEntry`

More information can be found in the [References](reference/references.md) and the [How-to guides](How_to/use_this_plugin.md).

<div markdown="block" class="home-grid">
<div markdown="block">

## How-to guides

How-to guides provide step-by-step instructions for a wide range of tasks, with the overarching topics:

- [Install this plugin](how_to/install_this_plugin.md)
- [Create catalysis related entries](how_to/use_this_plugin.md)
- [Search catalysis data](how_to/search_catalysis_data.md)

</div>

<div markdown="block">


## Reference

The reference [section](reference/references.md) includes a list of all sections and their quantities,
as well as the necessary format for the possible datafiles of the catalytic reaction.

</div>
</div>

## About NOMAD

NOMAD is an open-source data management platform tailored for materials science, designed to follow the FAIR principles. It offers a robust framework for managing and sharing materials data in a standardized and interoperable manner. To learn more about NOMAD, visit the [official homepage](https://nomad-lab.eu/nomad-lab/).

We hope this documentation provides all the information you need to make the most of the NOMAD Catalysis Plugin. Feel free to contact us for further questions, either via opening an issue in the [github repository](https://github.com/FAIRmat-NFDI/nomad-catalysis-plugin), asking in the NOMAD Discord channel, or reaching out directly to the [FAIRmat project](https://www.fairmat-nfdi.eu/fairmat/about-fairmat/contact-fairmat).